@@ -1,7 +1,11 @@
 use requestty::Question;
 
-fn letter_and_numbers(password: &str, _: &requestty::Answers) -> Result<(), String> {
-    if password.contains(|c: char| c.is_ascii_digit()) && password.contains(char::is_alphabetic) {
+fn is_valid(password: &str, _: &requestty::Answers) -> bool {
+    password.contains(|c: char| c.is_ascii_digit()) && password.contains(char::is_alphabetic)
+}
+
+fn letter_and_numbers(password: &str, ans: &requestty::Answers) -> Result<(), String> {
+    if is_valid(password, ans) {
         Ok(())
     } else {
         Err("Password needs to have at least 1 letter and 1 number.".to_owned())
@@ -17,6 +21,7 @@ fn main() {
         Question::password("password2")
             .message("Enter a masked password")
             .mask('*')
+            .validate_on_key(is_valid)
             .validate(letter_and_numbers)
             .build(),
     ];
